@@ -330,18 +330,17 @@ def build(branch, ngBuild='', ngApp='', angularBuild='', angularEnv='', installP
 
 
 @task
-def build2(javaEnv, dirs, prodSecrets="False",shard="",buildApi="True", buildWorker="True"):
+def build2(javaEnv, dirs, prodSecrets="False",shard="",buildApi="True", buildWorker="True", buildScheduler="False"):
 
     # ensure maven installs all build tools
 	local("pwd")
 	local('mvn clean install -DskipTests')
 
-	if buildApi in TRUTH_VALUES:
-	    local('mkdir -p deploy/api/config')
-	    local('mkdir -p deploy/api/lib')
-	 
+    if buildApi in TRUTH_VALUES:
+        local('mkdir -p deploy/api/config')
+        local('mkdir -p deploy/api/lib')
 
-	    local('cp config/logback.xml deploy/api/config/')
+        local('cp config/logback.xml deploy/api/config/')
         local('cp -r api/target/lib/ deploy/api/')
         local('cp api/target/*SNAPSHOT.jar deploy/api/')
 
@@ -352,20 +351,27 @@ def build2(javaEnv, dirs, prodSecrets="False",shard="",buildApi="True", buildWor
             local('cp config/keyset-%s.json deploy/api/config/keyset.json' % javaEnv)
     	    local('cp config/application-%s.yml deploy/api/config/' % javaEnv)
 
+    if buildScheduler in TRUTH_VALUES:
+        local('mkdir -p deploy/scheduler-worker/config')
+        local('mkdir -p deploy/scheduler-worker/lib')
+        local('cp config/logback.xml deploy/scheduler-worker/config/')
+        local('cp -r scheduler-worker/target/lib/ deploy/scheduler-worker/')
+        local('cp scheduler-worker/target/*SNAPSHOT.jar deploy/scheduler-worker/')
+        if prodSecrets in TRUTH_VALUES:
+            local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/scheduler-worker/config/keyset.json' % (javaEnv, shard))
+            local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/scheduler-worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
+        else:
+            local('cp config/keyset-%s.json deploy/scheduler-worker/config/keyset.json' % javaEnv)
+            local('cp config/application-%s.yml deploy/scheduler-worker/config/' % javaEnv)
 
-
-
-	if buildWorker in TRUTH_VALUES:
-	    local('mkdir -p deploy/worker/config')
-	    local('mkdir -p deploy/worker/lib')
-
-
+    if buildWorker in TRUTH_VALUES:
+        local('mkdir -p deploy/worker/config')
+        local('mkdir -p deploy/worker/lib')
         local('cp config/logback.xml deploy/worker/config/')
         local('cp config/initiate_shutdown.sql deploy/worker/config/')
         local('cp config/finish-deploy.sh deploy/worker/config/')
         local('cp -r worker/target/lib/ deploy/worker/')
         local('cp worker/target/*SNAPSHOT.jar deploy/worker/')
-
         if prodSecrets in TRUTH_VALUES:
             local('aws s3 cp s3://topopps-prod-x/keyset-%s-s%s.json deploy/worker/config/keyset.json' % (javaEnv, shard))
     	    local('aws s3 cp s3://topopps-prod-x/application-%s-s%s.yml deploy/worker/config/application-%s.yml' % (javaEnv, shard, javaEnv))
@@ -378,8 +384,6 @@ def build2(javaEnv, dirs, prodSecrets="False",shard="",buildApi="True", buildWor
 
 
 
-
-
 # Obtain git_sha from Jenkins git plugin, make sure it's passed along with the code so that
 # uwsgi, djangorq, and and celery can make use of it (e.g. to pass to
 # Sentry for releases)
